aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttributeProviderPlugin.java2
-rw-r--r--id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttribute_deprecatedProviderPlugin.java7
-rw-r--r--id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalDeprecatedType.java145
-rw-r--r--id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalType.java75
-rw-r--r--id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/ObjectFactory.java58
-rw-r--r--id/server/stork2-commons/src/main/resources/schema/StorkcomplexAttributes.xsd35
6 files changed, 267 insertions, 55 deletions
diff --git a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttributeProviderPlugin.java b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttributeProviderPlugin.java
index 902f41a4b..bd1576020 100644
--- a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttributeProviderPlugin.java
+++ b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttributeProviderPlugin.java
@@ -191,7 +191,7 @@ public class EHvdAttributeProviderPlugin extends AttributeProvider {
// TODO: we do not have any list of possible values yet. Fix as soon as we get some.
// if (collection.get("Type").equals("Medical doctor"))
- result.setHCPType("physician");
+ result.setTypeOfHCP("physician");
result.setNameOfOrganisation(collection.get("NameOfOrganisation"));
//result.setTypeOfOrganisation("Unknown"); // TODO used in previous version, check what to do with this
diff --git a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttribute_deprecatedProviderPlugin.java b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttribute_deprecatedProviderPlugin.java
index 22ff5e85c..a16603beb 100644
--- a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttribute_deprecatedProviderPlugin.java
+++ b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/protocols/stork2/attributeproviders/EHvdAttribute_deprecatedProviderPlugin.java
@@ -53,6 +53,7 @@ import eu.stork.peps.auth.commons.IPersonalAttributeList;
import eu.stork.peps.auth.commons.PersonalAttribute;
import eu.stork.peps.auth.commons.PersonalAttributeList;
import eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion.AttributeStatusType;
+import eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion.IsHealthCareProfessionalDeprecatedType;
import eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion.IsHealthCareProfessionalType; // IsHealthCareProfessionalDeprecatedType;
//import eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion. _1_0.assertion.IsHealthCareProfessionalType;
import eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion.ObjectFactory;
@@ -188,7 +189,7 @@ public class EHvdAttribute_deprecatedProviderPlugin extends AttributeProvider {
acquiredAttribute = new PersonalAttribute("isHealthCareProfessional", false, new ArrayList<String>(), AttributeStatusType.NOT_AVAILABLE.value());
} else {
// go on and parse the data
- IsHealthCareProfessionalType result = new IsHealthCareProfessionalType();
+ IsHealthCareProfessionalDeprecatedType result = new IsHealthCareProfessionalDeprecatedType();
result.setNameOfOrganisation(collection.get("NameOfOrganisation"));
if (collection.get("Type").equals("Medical doctor"))
@@ -203,11 +204,11 @@ public class EHvdAttribute_deprecatedProviderPlugin extends AttributeProvider {
result.setAQAA(4);
- final Marshaller m = JAXBContext.newInstance(IsHealthCareProfessionalType.class).createMarshaller();
+ final Marshaller m = JAXBContext.newInstance(IsHealthCareProfessionalDeprecatedType.class).createMarshaller();
m.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, true);
StringWriter stringWriter = new StringWriter();
- m.marshal(new ObjectFactory().createIsHealthCareProfessional(result), stringWriter);
+ m.marshal(new ObjectFactory().createIsHealthCareProfessionalDeprecated(result), stringWriter);
ArrayList<String> value = new ArrayList<String>();
value.add(stringWriter.toString());
diff --git a/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalDeprecatedType.java b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalDeprecatedType.java
new file mode 100644
index 000000000..711b7d68d
--- /dev/null
+++ b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalDeprecatedType.java
@@ -0,0 +1,145 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4-2
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
+// Any modifications to this file will be lost upon recompilation of the source schema.
+// Generated on: 2014.11.27 at 06:17:01 PM CET
+//
+
+
+package eu.stork.peps.complex.attributes.eu.stork.names.tc.stork._1_0.assertion;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for isHealthCareProfessional_deprecatedType complex type.
+ *
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ *
+ * <pre>
+ * &lt;complexType name="isHealthCareProfessional_deprecatedType">
+ * &lt;complexContent>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ * &lt;sequence>
+ * &lt;element name="nameOfOrganisation" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ * &lt;element ref="{urn:eu:stork:names:tc:STORK:1.0:assertion}HCPType"/>
+ * &lt;element ref="{urn:eu:stork:names:tc:STORK:1.0:assertion}specialisation"/>
+ * &lt;element name="AQAA" type="{urn:eu:stork:names:tc:STORK:1.0:assertion}QualityAuthenticationAssuranceLevelType"/>
+ * &lt;/sequence>
+ * &lt;/restriction>
+ * &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ *
+ *
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "isHealthCareProfessional_deprecatedType", propOrder = {
+ "nameOfOrganisation",
+ "hcpType",
+ "specialisation",
+ "aqaa"
+})
+public class IsHealthCareProfessionalDeprecatedType {
+
+ @XmlElement(required = true)
+ protected String nameOfOrganisation;
+ @XmlElement(name = "HCPType", required = true)
+ protected String hcpType;
+ @XmlElement(required = true)
+ protected String specialisation;
+ @XmlElement(name = "AQAA")
+ protected int aqaa;
+
+ /**
+ * Gets the value of the nameOfOrganisation property.
+ *
+ * @return
+ * possible object is
+ * {@link String }
+ *
+ */
+ public String getNameOfOrganisation() {
+ return nameOfOrganisation;
+ }
+
+ /**
+ * Sets the value of the nameOfOrganisation property.
+ *
+ * @param value
+ * allowed object is
+ * {@link String }
+ *
+ */
+ public void setNameOfOrganisation(String value) {
+ this.nameOfOrganisation = value;
+ }
+
+ /**
+ * Gets the value of the hcpType property.
+ *
+ * @return
+ * possible object is
+ * {@link String }
+ *
+ */
+ public String getHCPType() {
+ return hcpType;
+ }
+
+ /**
+ * Sets the value of the hcpType property.
+ *
+ * @param value
+ * allowed object is
+ * {@link String }
+ *
+ */
+ public void setHCPType(String value) {
+ this.hcpType = value;
+ }
+
+ /**
+ * Gets the value of the specialisation property.
+ *
+ * @return
+ * possible object is
+ * {@link String }
+ *
+ */
+ public String getSpecialisation() {
+ return specialisation;
+ }
+
+ /**
+ * Sets the value of the specialisation property.
+ *
+ * @param value
+ * allowed object is
+ * {@link String }
+ *
+ */
+ public void setSpecialisation(String value) {
+ this.specialisation = value;
+ }
+
+ /**
+ * Gets the value of the aqaa property.
+ *
+ */
+ public int getAQAA() {
+ return aqaa;
+ }
+
+ /**
+ * Sets the value of the aqaa property.
+ *
+ */
+ public void setAQAA(int value) {
+ this.aqaa = value;
+ }
+
+}
diff --git a/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/ObjectFactory.java b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/ObjectFactory.java
index b387aab99..217ca4ec4 100644
--- a/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/ObjectFactory.java
+++ b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/ObjectFactory.java
@@ -2,7 +2,7 @@
// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4-2
// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2014.10.09 at 10:11:43 AM GMT
+// Generated on: 2014.11.27 at 06:25:14 PM CET
//
@@ -40,6 +40,7 @@ public class ObjectFactory {
private final static QName _QualityAuthenticationAssuranceLevel_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "QualityAuthenticationAssuranceLevel");
private final static QName _IsAcademicStaff_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "isAcademicStaff");
private final static QName _MandateContent_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "mandateContent");
+ private final static QName _IsHealthCareProfessionalDeprecated_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "isHealthCareProfessional_deprecated");
private final static QName _CanonicalRegisteredAddress_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "canonicalRegisteredAddress");
private final static QName _SpCountry_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "spCountry");
private final static QName _IsAdminStaff_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "isAdminStaff");
@@ -47,8 +48,8 @@ public class ObjectFactory {
private final static QName _CountryCodeAddress_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "countryCodeAddress");
private final static QName _HasAccountInBank_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "hasAccountInBank");
private final static QName _CurrentStudiesSupplement_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "currentStudiesSupplement");
- private final static QName _RequestedAttribute_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "RequestedAttribute");
private final static QName _Mandate_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "mandate");
+ private final static QName _RequestedAttribute_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "RequestedAttribute");
private final static QName _SpSector_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "spSector");
private final static QName _HasDegree_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "hasDegree");
private final static QName _DiplomaSupplement_QNAME = new QName("urn:eu:stork:names:tc:STORK:1.0:assertion", "diplomaSupplement");
@@ -79,19 +80,19 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link RequestedAttributeType }
+ * Create an instance of {@link MandateType }
*
*/
- public RequestedAttributeType createRequestedAttributeType() {
- return new RequestedAttributeType();
+ public MandateType createMandateType() {
+ return new MandateType();
}
/**
- * Create an instance of {@link MandateType }
+ * Create an instance of {@link RequestedAttributeType }
*
*/
- public MandateType createMandateType() {
- return new MandateType();
+ public RequestedAttributeType createRequestedAttributeType() {
+ return new RequestedAttributeType();
}
/**
@@ -127,6 +128,14 @@ public class ObjectFactory {
}
/**
+ * Create an instance of {@link IsHealthCareProfessionalDeprecatedType }
+ *
+ */
+ public IsHealthCareProfessionalDeprecatedType createIsHealthCareProfessionalDeprecatedType() {
+ return new IsHealthCareProfessionalDeprecatedType();
+ }
+
+ /**
* Create an instance of {@link MandateContentType }
*
*/
@@ -231,14 +240,6 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link OriginalMandateType }
- *
- */
- /*public OriginalMandateType createOriginalMandateType() {
- return new OriginalMandateType();
- }*/
-
- /**
* Create an instance of {@link IsHCPType }
*
*/
@@ -310,6 +311,15 @@ public class ObjectFactory {
}
/**
+ * Create an instance of {@link JAXBElement }{@code <}{@link IsHealthCareProfessionalDeprecatedType }{@code >}}
+ *
+ */
+ @XmlElementDecl(namespace = "urn:eu:stork:names:tc:STORK:1.0:assertion", name = "isHealthCareProfessional_deprecated")
+ public JAXBElement<IsHealthCareProfessionalDeprecatedType> createIsHealthCareProfessionalDeprecated(IsHealthCareProfessionalDeprecatedType value) {
+ return new JAXBElement<IsHealthCareProfessionalDeprecatedType>(_IsHealthCareProfessionalDeprecated_QNAME, IsHealthCareProfessionalDeprecatedType.class, null, value);
+ }
+
+ /**
* Create an instance of {@link JAXBElement }{@code <}{@link CanonicalAddressType }{@code >}}
*
*/
@@ -375,21 +385,21 @@ public class ObjectFactory {
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link RequestedAttributeType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link MandateType }{@code >}}
*
*/
- @XmlElementDecl(namespace = "urn:eu:stork:names:tc:STORK:1.0:assertion", name = "RequestedAttribute")
- public JAXBElement<RequestedAttributeType> createRequestedAttribute(RequestedAttributeType value) {
- return new JAXBElement<RequestedAttributeType>(_RequestedAttribute_QNAME, RequestedAttributeType.class, null, value);
+ @XmlElementDecl(namespace = "urn:eu:stork:names:tc:STORK:1.0:assertion", name = "mandate")
+ public JAXBElement<MandateType> createMandate(MandateType value) {
+ return new JAXBElement<MandateType>(_Mandate_QNAME, MandateType.class, null, value);
}
/**
- * Create an instance of {@link JAXBElement }{@code <}{@link MandateType }{@code >}}
+ * Create an instance of {@link JAXBElement }{@code <}{@link RequestedAttributeType }{@code >}}
*
*/
- @XmlElementDecl(namespace = "urn:eu:stork:names:tc:STORK:1.0:assertion", name = "mandate")
- public JAXBElement<MandateType> createMandate(MandateType value) {
- return new JAXBElement<MandateType>(_Mandate_QNAME, MandateType.class, null, value);
+ @XmlElementDecl(namespace = "urn:eu:stork:names:tc:STORK:1.0:assertion", name = "RequestedAttribute")
+ public JAXBElement<RequestedAttributeType> createRequestedAttribute(RequestedAttributeType value) {
+ return new JAXBElement<RequestedAttributeType>(_RequestedAttribute_QNAME, RequestedAttributeType.class, null, value);
}
/**
diff --git a/id/server/stork2-commons/src/main/resources/schema/StorkcomplexAttributes.xsd b/id/server/stork2-commons/src/main/resources/schema/StorkcomplexAttributes.xsd
index 463b39ee2..1dfd6b319 100644
--- a/id/server/stork2-commons/src/main/resources/schema/StorkcomplexAttributes.xsd
+++ b/id/server/stork2-commons/src/main/resources/schema/StorkcomplexAttributes.xsd
@@ -27,6 +27,7 @@
<xs:element name="acTitle" type="stork:acTitleType"/>
<xs:element name="hasAccountInBank" type="stork:hasAccountInBankType"/>
<xs:element name="isHealthCareProfessional" type="stork:isHealthCareProfessionalType"/>
+<xs:element name="isHealthCareProfessional_deprecated" type="stork:isHealthCareProfessional_deprecatedType"/>
<xs:element name="canonicalRegisteredAddress" type="stork:canonicalAddressType"/>
<xs:element name="AQAA" type="stork:QualityAuthenticationAssuranceLevelType"/>
<xs:element name="mandate" type="stork:mandateType"/>
@@ -274,7 +275,7 @@
<xs:element name="AQAA" type="stork:QualityAuthenticationAssuranceLevelType"/>
</xs:sequence>
</xs:complexType>
-<xs:complexType name="isHealthCareProfessionalType">
+<xs:complexType name="isHealthCareProfessional_deprecatedType">
<xs:sequence>
<xs:element name="nameOfOrganisation" type="xs:string"/>
<xs:element ref="stork:HCPType"/>
@@ -360,4 +361,36 @@
<xs:minLength value="2"/>
</xs:restriction>
</xs:simpleType>
+
+ <xs:complexType name="isHealthCareProfessionalType">
+ <xs:sequence>
+ <xs:element name="typeOfHCP">
+ <xs:simpleType>
+ <xs:restriction base="xs:anyURI">
+ <xs:enumeration value="dentist" />
+ <xs:enumeration value="nurse" />
+ <xs:enumeration value="pharmacist" />
+ <xs:enumeration value="physician" />
+ <xs:enumeration value="nurse midwife" />
+ <xs:enumeration value="admission clerk" />
+ <xs:enumeration value="ancillary services" />
+ <xs:enumeration value="clinical services" />
+ </xs:restriction>
+ </xs:simpleType>
+ </xs:element>
+ <xs:element name="nameOfOrganisation" type="xs:string" />
+ <xs:element name="typeOfOrganisation">
+ <xs:simpleType>
+ <xs:restriction base="xs:anyURI">
+ <xs:enumeration value="Hospital" />
+ <xs:enumeration value="Resident Physician" />
+ <xs:enumeration value="Pharmacy" />
+ <xs:enumeration value="Other" />
+ <xs:enumeration value="Unknown" />
+ </xs:restriction>
+ </xs:simpleType>
+ </xs:element>
+ <xs:element name="AQAA" type="stork:QualityAuthenticationAssuranceLevelType" />
+ </xs:sequence>
+ </xs:complexType>
</xs:schema>
diff --git a/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalType.java b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalType.java
index d288cda12..be11e4ee8 100644
--- a/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalType.java
+++ b/id/server/stork2-commons/src/main/java/eu/stork/peps/complex/attributes/eu/stork/names/tc/stork/_1_0/assertion/IsHealthCareProfessionalType.java
@@ -2,7 +2,7 @@
// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4-2
// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2014.04.12 at 12:22:50 PM GMT
+// Generated on: 2014.11.27 at 06:17:01 PM CET
//
@@ -24,9 +24,32 @@ import javax.xml.bind.annotation.XmlType;
* &lt;complexContent>
* &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
* &lt;sequence>
+ * &lt;element name="typeOfHCP">
+ * &lt;simpleType>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI">
+ * &lt;enumeration value="dentist"/>
+ * &lt;enumeration value="nurse"/>
+ * &lt;enumeration value="pharmacist"/>
+ * &lt;enumeration value="physician"/>
+ * &lt;enumeration value="nurse midwife"/>
+ * &lt;enumeration value="admission clerk"/>
+ * &lt;enumeration value="ancillary services"/>
+ * &lt;enumeration value="clinical services"/>
+ * &lt;/restriction>
+ * &lt;/simpleType>
+ * &lt;/element>
* &lt;element name="nameOfOrganisation" type="{http://www.w3.org/2001/XMLSchema}string"/>
- * &lt;element ref="{urn:eu:stork:names:tc:STORK:1.0:assertion}HCPType"/>
- * &lt;element ref="{urn:eu:stork:names:tc:STORK:1.0:assertion}specialisation"/>
+ * &lt;element name="typeOfOrganisation">
+ * &lt;simpleType>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI">
+ * &lt;enumeration value="Hospital"/>
+ * &lt;enumeration value="Resident Physician"/>
+ * &lt;enumeration value="Pharmacy"/>
+ * &lt;enumeration value="Other"/>
+ * &lt;enumeration value="Unknown"/>
+ * &lt;/restriction>
+ * &lt;/simpleType>
+ * &lt;/element>
* &lt;element name="AQAA" type="{urn:eu:stork:names:tc:STORK:1.0:assertion}QualityAuthenticationAssuranceLevelType"/>
* &lt;/sequence>
* &lt;/restriction>
@@ -38,92 +61,92 @@ import javax.xml.bind.annotation.XmlType;
*/
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "isHealthCareProfessionalType", propOrder = {
+ "typeOfHCP",
"nameOfOrganisation",
- "hcpType",
- "specialisation",
+ "typeOfOrganisation",
"aqaa"
})
public class IsHealthCareProfessionalType {
@XmlElement(required = true)
+ protected String typeOfHCP;
+ @XmlElement(required = true)
protected String nameOfOrganisation;
- @XmlElement(name = "HCPType", required = true)
- protected String hcpType;
@XmlElement(required = true)
- protected String specialisation;
+ protected String typeOfOrganisation;
@XmlElement(name = "AQAA")
protected int aqaa;
/**
* Gets the value of the nameOfOrganisation property.
*
* @return
* possible object is
* {@link String }
*
*/
- public String getNameOfOrganisation() {
- return nameOfOrganisation;
+ public String getTypeOfHCP() {
+ return typeOfHCP;
}
/**
* Sets the value of the nameOfOrganisation property.
*
* @param value
* allowed object is
* {@link String }
*
*/
- public void setNameOfOrganisation(String value) {
- this.nameOfOrganisation = value;
+ public void setTypeOfHCP(String value) {
+ this.typeOfHCP = value;
}
/**
- * Gets the value of the hcpType property.
+ * Gets the value of the nameOfOrganisation property.
*
* @return
* possible object is
* {@link String }
*
*/
- public String getHCPType() {
- return hcpType;
+ public String getNameOfOrganisation() {
+ return nameOfOrganisation;
}
/**
- * Sets the value of the hcpType property.
+ * Sets the value of the nameOfOrganisation property.
*
* @param value
* allowed object is
* {@link String }
*
*/
- public void setHCPType(String value) {
- this.hcpType = value;
+ public void setNameOfOrganisation(String value) {
+ this.nameOfOrganisation = value;
}
/**
* Gets the value of the specialisation property.
*
* @return
* possible object is
* {@link String }
*
*/
- public String getSpecialisation() {
- return specialisation;
+ public String getTypeOfOrganisation() {
+ return typeOfOrganisation;
}
/**
* Sets the value of the specialisation property.
*
* @param value
* allowed object is
* {@link String }
*
*/
- public void setSpecialisation(String value) {
- this.specialisation = value;
+ public void setTypeOfOrganisation(String value) {
+ this.typeOfOrganisation = value;
}
/**
@@ -38,92 +61,92 @@ import javax.xml.bind.annotation.XmlType;
protected int aqaa;
/**
- * Gets the value of the nameOfOrganisation property.
+ * Gets the value of the typeOfHCP property.
*
* @return
@@ -38,92 +61,92 @@ import javax.xml.bind.annotation.XmlType;
}
/**
- * Sets the value of the nameOfOrganisation property.
+ * Sets the value of the typeOfHCP property.
*
* @param value
@@ -38,92 +61,92 @@ import javax.xml.bind.annotation.XmlType;
}
/**
- * Gets the value of the specialisation property.
+ * Gets the value of the typeOfOrganisation property.
*
* @return
@@ -38,92 +61,92 @@ import javax.xml.bind.annotation.XmlType;
}
/**
- * Sets the value of the specialisation property.
+ * Sets the value of the typeOfOrganisation property.
*
* @param value